@@ -29,4 +29,13 @@ class Constants:
     FABRIC_TOKEN_LOCATION = "FABRIC_TOKEN_LOCATION"
     FABRIC_CREDMGR_HOST = "FABRIC_CREDMGR_HOST"
     FABRIC_ORCHESTRATOR_HOST = "FABRIC_ORCHESTRATOR_HOST"
-    FABRIC_PROJECT_ID = "FABRIC_PROJECT_ID"
\ No newline at end of file
+    FABRIC_CORE_API_HOST = "FABRIC_CORE_API_HOST"
+    FABRIC_AM_HOST = "FABRIC_AM_HOST"
+    FABRIC_PROJECT_ID = "FABRIC_PROJECT_ID"
+    FABRIC_PROJECT_NAME = "FABRIC_PROJECT_NAME"
+    FABRIC_COOKIE_NAME = "FABRIC_COOKIE_NAME"
+    COMMENT = "comment"
+    DESCRIPTION = "description"
+    KEY_TYPE = "keytype"
+    STORE_PUBKEY = "store_pubkey"
+
